package com.capgemini.shop.business;

import com.capgemini.shop.common.Logger;
import com.capgemini.shop.common.View;
import com.capgemini.shop.view.*;
import com.capgemini.shop.database.*;
import java.io.Serializable;
import java.sql.*;
import java.util.*;

public class ShopejbOrderMainpart implements Serializable
{
        private String command = null; // The name of the command coming from user
	private String search_name = null; // The search criteria
        private String which_one = null; // Selected product to add
	private List<ProductMainValue> search_list = null; // Search results
	private Map<String, ProductMainValue> product_map = null;
	private OrderMainHelper helper = null; // JSP helper to be send to front
	private OrderMainValue value = null; // This order 
        private int message=-1; // Hard coded messages to be sent to front
        
        // This map helps to keep code simplier
        private Map<String, OrderProductReferenceValue> order_product_map = null;

        // Constructor        
        public ShopejbOrderMainpart()
        {
                clear();
        }

	public void executeCommand(View original_data)
	{
		OrderMainView data = (OrderMainView) original_data;
		updateFields(data);

		if (command.equals("search"))
		{
			search();
		}
		else if (command.equals("add"))
		{
			add();
		}
		else if (command.equals("save"))
		{
			save();
		}
		else if (command.equals("clear"))
		{
			clear();
		}
                else
                {
                  Logger.debug("ShopejbOrderMainpart", "Unknown command (" + command + ")");
                }

		generateJspHelper();
	}

	public OrderMainHelper getJspHelper()
	{
		return(helper);
	}

	private void generateJspHelper()
	{
		helper = new OrderMainHelper();
		helper.setSearchList(search_list);
		helper.setValue(value);
		helper.setSearchCriteria(search_name);
                helper.setMessage(message);
		helper.setProductMap(product_map);
	}

	private void updateFields(OrderMainView data)
	{
                message=-1;

                command = data.getParameter("command");
                search_name = data.getParameter("search_name");
                which_one = data.getParameter("which_one");

                value.setAddress( data.getParameter("address") );
                value.setName( data.getParameter("name") );
                value.setPhoneNumber( data.getParameter("phone_number") );
	        
		if ( (value != null) && (value.getProductList() != null) && (value.getProductList().size() > 0) )
	        {
			int count = 0;
			for (OrderProductReferenceValue row : value.getProductList())
			{	
				try
				{
					int old_pieces = Integer.parseInt( data.getParameter("pieces" + (count++)) );
				        row.setNumberOfItems( old_pieces );
				}
				catch (Exception e)
				{
					e.printStackTrace();
					message = 2;
				}
			}
		}
	} // update()

	private void search()
	{
		Logger.debug("ShopejbOrderMainpart", "search()");
		try
		{
			Connection connection = Shopejb.getConnection();
			search(connection);
			connection.close();
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	private void search(Connection connection)
	{
		Logger.debug("ShopejbOrderMainpart", "search(connection)");
		try
		{
			ProductMainValue criteria = new ProductMainValue();
			
			if ((search_name != null) && (!search_name.trim().equals("")))
			{
			    criteria.setName("%" + search_name + "%");
			}
			
			search_list = ProductMainDao.search(connection, criteria);
			
			product_map = new HashMap<String, ProductMainValue>();
			for (ProductMainValue row : search_list)
			{
				product_map.put(row.getId() + "", row);
			}
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	private void save()
	{
		Logger.debug("ShopejbOrderMainpart", "save()");
		int old_id = value.getId();

                try
                {
                        Connection connection = Shopejb.getConnection();
                        OrderMainDao.save( connection, value );
                        search(connection);
			connection.close();
			
			message=0;
                }
                catch (Exception e)
                {
                        e.printStackTrace();
			message=1;
			value.setId(old_id);
                }

	}

	private void clear()
	{
		Logger.debug("ShopejbOrderMainpart", "clear()");
		search_list = null;
		search_name = null;
                value = new OrderMainValue();
                order_product_map = new HashMap<String, OrderProductReferenceValue>();
                
                search();
	}
        
        private void add()
        {
                Logger.debug("ShopejbOrderMainpart", "add(" + which_one + ")");
      
                OrderProductReferenceValue product = order_product_map.get(which_one);
                
                if (product == null)
                {
			Logger.debug("ShopejbOrderMainpart", "- this one is new in this order");
                        product = new OrderProductReferenceValue();
                        product.setProductReference(Integer.parseInt(which_one));
                        product.setNumberOfItems(1);
                        value.addProduct(product);
                        
                        order_product_map.put(which_one, product);
                }
                else 
                {
			Logger.debug("ShopejbOrderMainpart", "- add again");
                        product.setNumberOfItems( product.getNumberOfItems() + 1 );
                }
        }

} // class
