package com.capgemini.shop.database;

import com.capgemini.shop.common.Logger;
import java.sql.*;
import java.util.List;
import java.util.LinkedList;

/**
 * Searches, loads and saves OrderMainValue objects.
 */
public class OrderMainDao
{
	/*
	 * @param criteria has to be not null
	 */
	public static List<OrderMainValue> search(Connection connection, OrderMainValue criteria)
	{
		List<OrderMainValue> results = new LinkedList<OrderMainValue>();

		try
		{
			StringBuffer where = new StringBuffer(" where deleted=0");
			String sql = 
				"select address,phone_number,name,id from order_main";

			if ( (criteria.getAddress() != null) && (!(criteria.getAddress().equals(""))) )
			{
				where.append(" and ");
				where.append("lower(address) like ?");
			}

			if ( (criteria.getPhoneNumber() != null) && (!(criteria.getPhoneNumber().equals(""))) )
			{
				where.append(" and ");
				where.append("lower(phone_number) like ?");
			}

			if ( (criteria.getName() != null) && (!(criteria.getName().equals(""))) )
			{
				where.append(" and ");
				where.append("lower(name) like ?");
			}

			if (criteria.getId() > -1)
			{
				where.append(" and ");
				where.append("id=").append(criteria.getId());
			}


			sql += where;

			int count = 1;

			PreparedStatement statement = connection.prepareStatement(sql);

			if ( (criteria.getAddress() != null) && (!(criteria.getAddress().equals(""))) )
			{
				statement.setString(count++, criteria.getAddress().toLowerCase());
			}

			if ( (criteria.getPhoneNumber() != null) && (!(criteria.getPhoneNumber().equals(""))) )
			{
				statement.setString(count++, criteria.getPhoneNumber().toLowerCase());
			}

			if ( (criteria.getName() != null) && (!(criteria.getName().equals(""))) )
			{
				statement.setString(count++, criteria.getName().toLowerCase());
			}

			Logger.debug("OrderMainDao",sql);
			ResultSet resultset = statement.executeQuery();

			OrderMainValue data;
			while ( resultset.next() )
			{
				data = new OrderMainValue();
				data.setAddress( resultset.getString("address") );
				data.setPhoneNumber( resultset.getString("phone_number") );
				data.setName( resultset.getString("name") );
				data.setId( resultset.getInt("id") );

				results.add(data);
			}

			Logger.debug("OrderMainDao","rows: " + results.size());
			resultset.close();
			statement.close();
		} // try
		catch (Exception e)
		{
			e.printStackTrace();
		} // catch

		return (results);
	} // search()

	 /*
	  * @param criteria has to be not null
	  */
	 public static OrderMainValue get(Connection connection, int id)
	 {
	         try
	         {
	                 String sql = 
	                         "select address,phone_number,name,id from order_main where id=" + id;

	                 PreparedStatement statement = connection.prepareStatement(sql);

	                 Logger.debug("OrderMainDao",sql);
	                 ResultSet resultset = statement.executeQuery();

	                 OrderMainValue data = null;
	                 if ( resultset.next() )
	                 {
	                         data = new OrderMainValue();
	                         data.setAddress( resultset.getString("address") );
	                         data.setPhoneNumber( resultset.getString("phone_number") );
	                         data.setName( resultset.getString("name") );
	                         data.setId( resultset.getInt("id") );
	                 }

	                 resultset.close();
	                 statement.close();
                         
                         OrderProductReferenceValue criteria = new OrderProductReferenceValue();
                         criteria.setOrderReference(id);
                         data.setProductList(OrderProductReferenceDao.search(connection, criteria));
                         
                         return(data);
	         } // try
	         catch (Exception e)
	         {
	                 e.printStackTrace();
                         return(null);
	         } // catch
	 } // get()

	/*
	 * Saves a OrderMainValue to the database.
	 */
	public static void  save(Connection connection, OrderMainValue data) throws Exception
	{
		boolean new_one = (data.getId() == -1);

		int newid = -1;
		String sql;
		if (new_one)
		{
			Statement statement = connection.createStatement();
			String sql_sequence = "select nextval('seq_order_main_id')";
			Logger.debug("OrderMainDao", sql_sequence);
			ResultSet resultset = 
				statement.executeQuery(sql_sequence);

			if (resultset.next())
			{
				newid = resultset.getInt(1);
			}

			resultset.close();
			statement.close();
			Logger.debug("OrderMainDao","value: " + newid);
			data.setId(newid);

			sql = 
			"insert into order_main (address,phone_number,name,deleted,id) values (?,?,?,0,?)";
		}
		else
		{
			newid = data.getId();
			sql = "update order_main set address=?,phone_number=?,name=? where id=?";
		}


		PreparedStatement statement = connection.prepareStatement(sql);

		statement.setString( 1, data.getAddress() );
		statement.setString( 2, data.getPhoneNumber() );
		statement.setString( 3, data.getName() );
		statement.setInt( 4, newid );

		Logger.debug("OrderMainDao",sql);
		statement.executeUpdate();

		Logger.debug("OrderMainDao","order_main " + newid + " saved");
		statement.close();
		
		int count = 0;
		for (OrderProductReferenceValue row : data.getProductList())
		{
		  row.setOrderReference(newid);
		  row.setOrderNumber(count++);
		  OrderProductReferenceDao.save(connection, row);
		}


	} // save()

} // class
