package com.capgemini.shop.database;

import com.capgemini.shop.common.Logger;
import java.sql.*;
import java.util.List;
import java.util.LinkedList;

/**
 * Searches, loads and saves OrderProductReferenceValue objects.
 */
public class OrderProductReferenceDao
{
	/*
	 * @param criteria has to be not null
	 */
	public static List<OrderProductReferenceValue> search(Connection connection, OrderProductReferenceValue criteria)
	{
		List<OrderProductReferenceValue> results = new LinkedList<OrderProductReferenceValue>();

		try
		{
			StringBuffer where = new StringBuffer(" where deleted=0");
			String sql = 
				"select number_of_items,product_reference,order_reference,order_number,id from order_product_reference";

			if (criteria.getNumberOfItems() > -1)
			{
				where.append(" and ");
				where.append("number_of_items=").append(criteria.getNumberOfItems());
			}

			if (criteria.getProductReference() > -1)
			{
				where.append(" and ");
				where.append("product_reference=").append(criteria.getProductReference());
			}

			if (criteria.getOrderReference() > -1)
			{
				where.append(" and ");
				where.append("order_reference=").append(criteria.getOrderReference());
			}

			if (criteria.getOrderNumber() > -1)
			{
				where.append(" and ");
				where.append("order_number=").append(criteria.getOrderNumber());
			}

			if (criteria.getId() > -1)
			{
				where.append(" and ");
				where.append("id=").append(criteria.getId());
			}


			sql += where + " order by order_number";

			PreparedStatement statement = connection.prepareStatement(sql);


			Logger.debug("OrderProductReferenceDao",sql);
			ResultSet resultset = statement.executeQuery();

			OrderProductReferenceValue data;
			while ( resultset.next() )
			{
				data = new OrderProductReferenceValue();
				data.setNumberOfItems( resultset.getInt("number_of_items") );
				data.setProductReference( resultset.getInt("product_reference") );
				data.setOrderReference( resultset.getInt("order_reference") );
				data.setOrderNumber( resultset.getInt("order_number") );
				data.setId( resultset.getInt("id") );

				results.add(data);
			}

			Logger.debug("OrderProductReferenceDao","rows: " + results.size());
			resultset.close();
			statement.close();
		} // try
		catch (Exception e)
		{
			e.printStackTrace();
		} // catch

		return (results);
	} // search()

	/*
	 * Saves a OrderProductReferenceValue to the database.
	 */
	public static void  save(Connection connection, OrderProductReferenceValue data) throws Exception
	{
		boolean new_one = (data.getId() == -1);
		int newid = -1;
		String sql;
		if (new_one)
		{
			Statement statement = connection.createStatement();
			String sql_sequence = "select nextval('seq_order_product_reference_id')";
			Logger.debug("OrderProductReferenceDao", sql_sequence);
			ResultSet resultset = 
				statement.executeQuery(sql_sequence);

			if (resultset.next())
			{
				newid = resultset.getInt(1);
			}

			resultset.close();
			statement.close();
			Logger.debug("OrderProductReferenceDao","value: " + newid);
			data.setId(newid);

			sql = 
			"insert into order_product_reference (number_of_items,product_reference,order_reference,order_number,deleted,id) values (?,?,?,?,0,?)";
		}
		else
		{
			newid = data.getId();
			sql = "update order_product_reference set number_of_items=?,product_reference=?,order_reference=?,order_number=? where id=?";
		}


		PreparedStatement statement = connection.prepareStatement(sql);

		statement.setInt( 1, data.getNumberOfItems() );
		statement.setInt( 2, data.getProductReference() );
		statement.setInt( 3, data.getOrderReference() );
		statement.setInt( 4, data.getOrderNumber() );
		statement.setInt( 5, newid );

		Logger.debug("OrderProductReferenceDao",sql);
		statement.executeUpdate();

		Logger.debug("OrderProductReferenceDao","order_product_reference " + newid + " saved");
		statement.close();

	} // save()

} // class
