package com.capgemini.shop.database;

import com.capgemini.shop.common.Logger;
import java.sql.*;
import java.util.List;
import java.util.LinkedList;

/**
 * Searches, loads and saves ProductMainValue objects.
 */
public class ProductMainDao
{
	/*
	 * @param criteria has to be not null
	 */
	public static List<ProductMainValue> search(Connection connection, ProductMainValue criteria)
	{
		List<ProductMainValue> results = new LinkedList<ProductMainValue>();

		try
		{
			StringBuffer where = new StringBuffer(" where deleted=0");
			String sql = 
				"select price,name,id from product_main";

			if (criteria.getPrice() > -1)
			{
				where.append(" and ");
				where.append("price=").append(criteria.getPrice());
			}

			if ( (criteria.getName() != null) && (!(criteria.getName().equals(""))) )
			{
				where.append(" and ");
				where.append("lower(name) like ?");
			}

			if (criteria.getId() > -1)
			{
				where.append(" and ");
				where.append("id=").append(criteria.getId());
			}


			sql += where + " order by name";

			int count = 1;

			PreparedStatement statement = connection.prepareStatement(sql);


			if ( (criteria.getName() != null) && (!(criteria.getName().equals(""))) )
			{
				statement.setString(count++, criteria.getName().toLowerCase());
			}

			Logger.debug("ProductMainDao",sql);
			ResultSet resultset = statement.executeQuery();

			ProductMainValue data;
			while ( resultset.next() )
			{
				data = new ProductMainValue();
				data.setPrice( resultset.getFloat("price") );
				data.setName( resultset.getString("name") );
				data.setId( resultset.getInt("id") );

				results.add(data);
			}

			Logger.debug("ProductMainDao","rows: " + results.size());
			resultset.close();
			statement.close();
		} // try
		catch (Exception e)
		{
			e.printStackTrace();
		} // catch

		return (results);
	} // search()

	/*
	 * Saves a ProductMainValue to the database.
	 */
	public static void  save(Connection connection, ProductMainValue data)
	{
		boolean new_one = (data.getId() == -1);
		try
		{
			int newid = -1;
			String sql;
			if (new_one)
			{
				Statement statement = connection.createStatement();
				String sql_sequence = "select nextval('seq_product_main_id')";
				Logger.debug("ProductMainDao", sql_sequence);
				ResultSet resultset = 
					statement.executeQuery(sql_sequence);

				if (resultset.next())
				{
					newid = resultset.getInt(1);
				}

				resultset.close();
				statement.close();
				Logger.debug("ProductMainDao","value: " + newid);
				data.setId(newid);

				sql = 
				"insert into product_main (price,name,id) values (?,?,?)";
			}
			else
			{
				newid = data.getId();
				sql = "update product_main set price=?,name=? where id=?";
			}


			PreparedStatement statement = connection.prepareStatement(sql);

			statement.setFloat( 1, data.getPrice() );
			statement.setString( 2, data.getName() );
			statement.setInt( 3, newid );

			Logger.debug("ProductMainDao",sql);
			statement.executeUpdate();

			Logger.debug("ProductMainDao","product_main " + newid + " saved");
			statement.close();
		} // try
		catch (Exception e)
		{
			if (new_one)
			{
				data.setId(-1);
			}

			e.printStackTrace();
		} // catch

	} // save()

} // class
