package com.capgemini.shop.view;

import com.capgemini.shop.database.OrderMainValue;
import com.capgemini.shop.database.OrderProductReferenceValue;
import com.capgemini.shop.database.ProductMainValue;
import java.io.Serializable;
import java.util.*;

/**
 * EJB returns this object to command, and JSP uses it (&quot;bean&quot;)
 * &quot;One order (for one person)&quot;
 */
public class OrderMainHelper implements Serializable
{
	private List<ProductMainValue> search_list = null;
	private OrderMainValue value = null;
        private int message = -1;
	private String search_name = null;
	private Map<String, ProductMainValue> product_map = null;

	public void setSearchCriteria(String search_name)
	{
		this.search_name = search_name;
	}
	
	public void setProductMap(Map<String, ProductMainValue> data)
	{
		product_map = data;
	}

	public void setSearchList(List<ProductMainValue> data)
	{
		search_list = data;
	}

	public void setValue(OrderMainValue data)
	{
		value = data;
	}

        public void setMessage(int data)
        {
                message = data;
        }
	
	private String formatEuros(float data)
	{
		String ret = (data + .005) + ""; // round
		ret = ret.substring(0, ret.indexOf('.') + 3); // cut
		return(ret);
	}

        public String getSearchResults()
        {
                StringBuffer ret = new StringBuffer();
		
		if (search_list == null)
		{
			// Do nothing - is this possible even?
		}
		else if (search_list.size() == 0)
		{
			ret.append("<tr><td colspan=\"3\">No search results with the given criteria</td></tr>");
		}
		else 
		{
			for (ProductMainValue row : search_list)
			{
				ret.append("<tr>");
				ret.append("<td>").append( row.getName() ).append("</td>");
			        ret.append("<td>").append( formatEuros(row.getPrice()) ).append("</td>");
			        ret.append("<td><input type=\"button\" value=\"Add ->\" onclick=\"document.mainform.which_one.value='")
					.append(row.getId())
					.append("';document.mainform.command.value='add';document.mainform.submit()\"/></td>");
			        ret.append("</tr>");
			}
		}
		
		return(ret.toString());
        }
	
	public String getOrder()
	{
		StringBuffer ret = new StringBuffer();
		
		if ( (value != null) && (value.getProductList() != null) && (value.getProductList().size() > 0) )
		{
			ret.append("<h1>Your Order</h1>");
			ret.append("<table>");
			ret.append("<tr>");
			ret.append("<th>Item</th>");
		        ret.append("<th>Pieces</th>");
		        ret.append("<th>Price</th>");
		        ret.append("<th>TOTAL</th>");
		        ret.append("</tr>");

			int count = 0;
		        for (OrderProductReferenceValue row : value.getProductList())
		        {
				ProductMainValue product = product_map.get(row.getProductReference() + "");
		                ret.append("<tr>");
		                ret.append("<td>").append( product.getName() ).append("</td>");
		                ret.append("<td><input type=\"text\" value=\"").append( row.getNumberOfItems() ).append("\" name=\"pieces").append(count++).append("\" /></td>");
		                ret.append("<td>").append( formatEuros(product.getPrice()) ).append("</td>");
		                ret.append("<td>").append( formatEuros(row.getNumberOfItems() * product.getPrice()) ).append("</td>");
		                ret.append("</tr>");
		        }

		        ret.append("</table>");
		}
		
		return(ret.toString());
	}
	
	private String notNull(String data)
	{
		if (data == null)
		{
			return("");
		}
		else
		{
			return(data.replaceAll("\"", "&quot;"));
		}
	}
	
	public String getSearchName()
	{
		return(notNull(search_name));
	}
	
	public String getName()
	{
		return(notNull(value.getName()));
	}

	public String getPhoneNumber()
	{
		return(notNull(value.getPhoneNumber()));
	}
	
	public String getAddress()
	{
		return(notNull(value.getAddress()));
	}	
	
        public String getSaveLabel()
	{
		return(value.getId() == -1 ? "Save" : "Update");
	}
	
	private String getDateTime()
	{
	        Calendar calendar=new GregorianCalendar();

	        String minutesnow = "";
	        String hoursnow = "";
		String secondsnow = "";
	        int second = calendar.get(Calendar.SECOND);
	        int minute = calendar.get(Calendar.MINUTE);
	        int hour = calendar.get(Calendar.HOUR_OF_DAY);

		if (second < 10)
		{
			secondsnow = "0";
		}
		secondsnow += second;
		
	        if (minute < 10) 
	        {
	                minutesnow = "0";
	        }
	        minutesnow += minute;

	        if (hour < 10) 
	        {
	                hoursnow = "0";
	        }
	        hoursnow += hour;

	        return(hoursnow + "." + minutesnow + "." + secondsnow);
	}
	
	public String getMessage()
	{
		String ret = "";
		if (message == 0)
		{
			ret = "Saving succeeded at " + getDateTime();
		}
		else if (message == 1)
		{
			ret = "Saving FAILED at " + getDateTime();
		}
	        else if (message == 2)
	        {
	                ret = "Invalid number format for &quot;Pieces&quot; ";
	        }
		
		return(ret);
	}
	
} // class
